import React, { useEffect } from 'react';
import { useRoomsState, useToggleView } from '../../../store/store';
import { computeArea } from '../functions/computeArea';
import { Html } from '@react-three/drei';
import * as CONSTANTS from "../../../types/world/worldConstants";
import * as turf from '@turf/turf';

const CalculateAreaGroup = () => {
    const { roomsState } = useRoomsState();
    const { toggleView } = useToggleView();

    return (
        <group name="roomArea" visible={toggleView}>
            {roomsState.length > 0 &&
                roomsState.flat().map((room: any, index: number) => {
                    if (!toggleView) return null;
                    const coordinates = room.coordinates;

                    if (!coordinates || coordinates.length < 3) return null;

                    let coords2D = coordinates.map((p: any) => [p.position.x, p.position.z]);

                    const first = coords2D[0];
                    const last = coords2D[coords2D.length - 1];
                    if (first[0] !== last[0] || first[1] !== last[1]) {
                        coords2D.push(first);
                    }

                    const polygon = turf.polygon([coords2D]);
                    const center2D = turf.center(polygon).geometry.coordinates;

                    const sumY = coordinates.reduce((sum: number, p: any) => sum + p.position.y, 0);
                    const avgY = sumY / coordinates.length;

                    const area = computeArea(room, "rooms");
                    const formattedArea = `${area.toFixed(2)} m²`;

                    const htmlPosition: [number, number, number] = [
                        center2D[0],
                        avgY + CONSTANTS.zoneConfig.height,
                        center2D[1],
                    ];

                    return (
                        <Html
                            key={`${index}-${room.layer || index}`}
                            position={htmlPosition}
                            wrapperClass="distance-text-wrapper"
                            className="distance-text"
                            zIndexRange={[1, 0]}
                            prepend
                            center
                            sprite
                        >
                            <div className={`distance area line-${room.layer || index}`}>
                                Room ({formattedArea})
                            </div>
                        </Html>
                    );
                })}
        </group>
    );
}

export default CalculateAreaGroup;
